Module: Indis
- Defined in:
- lib/indis-core/vmmap.rb,
lib/indis-core.rb,
lib/indis-core/entity.rb,
lib/indis-core/symbol.rb,
lib/indis-core/target.rb,
lib/indis-core/section.rb,
lib/indis-core/segment.rb,
lib/indis-core/version.rb,
lib/indis-core/data_entity.rb,
lib/indis-core/binary_format.rb,
lib/indis-core/cstring_entity.rb,
lib/indis-core/binary_architecture.rb
Overview
Indis framework # Copyright (C) 2012 Vladimir "Farcaller" Pouzanov [email protected] # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU General Public License for more details. # # You should have received a copy of the GNU General Public License # along with this program. If not, see http://www.gnu.org/licenses/. #
Defined Under Namespace
Modules: BinaryArchitecture, BinaryFormat Classes: CStringEntity, DataEntity, Entity, Section, Segment, Symbol, Target, VMMap
Constant Summary collapse
- VERSION =
"0.1.4"